/**
 * @author v_wangyan
 * @create 2012-11-05
 * @update 2013-08-08
 */ 
var skin = window.skin || {};
/**
 * 获取元素对象
 * @param  {string} element 元素id
 * @return {object}         返回元素对象
 */
skin.g = function(element) {
    return document.getElementById(element) || element;
}
/**
 * 转换JSON对象
 * @param  {string} jsonString json字符串
 * @return {object}            json对象
 */
skin.jsonDecode =function(jsonString) {
	return (new Function("return " + jsonString))();
}
/**
 * 设置字体
 * @param {int}   
 * @return void
 */
skin.setFontFamily = function (key) {   //设置字体:  0-宋体 ; 1-微软雅黑;
    key = key || '0';
    var obj = document.body;
    var font = '';
    if (key) {
        font = '"微软雅黑", "宋体", Arial, Verdana';
    } else {
        font = '"宋体", "微软雅黑", Arial, Verdana';
    }
    obj.style.fontFamily = font;
}
/**
 * 设置页面显示的字体(win7--雅黑字,其他为宋体)
 * @param 无
 * @return string
 */
skin.getSysver = function () {
    var key = 0;
    try {
        key = execOrder('sysver');
        if ('6.1' == key) {
            key = 1;
        }
    } catch (e) {   }   
    
    skin.setFontFamily(key); 
}
/**
 * 处理icon点击
 * @param  {event} e          事件
 * @param  {bool} rightClick 是否为右键(点击)
 * @param  {number} key        iconid
 * @return {void}            无
 */
skin.execMouseDown = function (e, rightClick, key) {
    //取消冒泡事件
    e.stopPropagation(); 
    
    var order = rightClick ? 'mouseRDown' : 'mouseLDown';
    try {
        window.external.SyncRequest(order, key);
    } catch (e) {}  
},
/**
 * 处理右键点击
 * @param  {string} id elementid
 * @return {void}    无
 */
skin.rightButton = function (id) {
    if (event.button == 2) {
       skin.execMouseDown(event, true, id);
    }
},
/**
 * 执行命令
 * @param {string} 命令名称
 * @param {string} 值
 * @return string | void
 */
skin.execOrder = function (order, key) {
    var info = '';
    try { 
        key = (key.length == 0 ? '0' : key); 
        info = window.external.SyncRequest(order, key);
    } catch (e) {       
    } 
    return info;
},
/**
 * 执行客户端命令,获取参数
 * @param  {string} order 命令名称
 * @param  {string} param 参数
 * @return {void|object}       无|-
 */
skin.execSync = function (order, param) {
    try {
        if (window.external.SyncRequest) {
            return window.external.SyncRequest(order, param);
        } 
    } catch (e) {
        return '';
    }
    return '';
},
/**
 * 设置本地存储--(使用)获取到对应参数值,进行赋值后重新存储该值
 * @type {Object}
 */
skin.storage = {
    set: function (key, value) {
        this.data(key, value);
    },
    get: function (key) {  
        return this.data(key);
    },
    /**
     * 处理存储数据
     * @param  {string} key   存储(获取的)key
     * @param  {[type]} value 存储的值
     * @return {boolea | object}       操作结果
     */
    data: function (key, value) { 
        var configData = skin.execSync('readConfig') || '{}'; 
        if (typeof configData  == 'string') {
            configData = JSON.parse(configData);
        }         
        if (value) {     
            configData[key] = value;
            skin.execSync('saveConfig', JSON.stringify(configData));            
            return true;
        } else {                                 
            return (key ? (configData[key] || false) : configData);
        }
        return false;
    }
},
//获取RD数据status,null 时返回当前状态
/**
 * 设置icon状态
 * @param  {string} id  icon的id
 * @param  {string} key 命令
 * @return {void}     无
 */
skin.getExecStatus = function (id, key) {  
    if (typeof skin.g(id) == 'string') {
        return;
    }
    var statu = skin.execSync('getButtonState', key) || skin.g(id).getAttribute('statu'); 
    return statu;
},
/**
 * 初始输入法状态  
 * 参数:0 (中英文切换) 返回值: 0 英文 1 中文;
 * 参数:1 (全半角切换) 返回值: 0 半角 1 全角; 
 * 参数:2 (中英文标点) 返回值: 0 英文标点 1 中文标点;
 * 参数:3 (软键盘)
 * 参数:4 (登录)            返回值: 0 未登录 1 已登录
 * 参数:5 (配置)
 */
skin.setIMEStatus = function () { 
    setButtonState('0', skin.getExecStatus('language', '0'));    
    setButtonState('1', skin.getExecStatus('characters', '1'));  
    setButtonState('2', skin.getExecStatus('punctuation', '2')); 
    setButtonState('5', skin.getExecStatus('setting', '5'));   
}
/**
 * 绑定输入法icon点击/hover等事件
 * @return {void} 无
 */
skin.bindEvent = function () {
    var icons = skin.g('iconEvent').getElementsByTagName('img');
    for (var i = 0, len = icons.length; i < len; i++) {        
        icons[i].onclick = function () { 
            skin.execMouseDown(event, false, this.getAttribute('key'));
        }
        icons[i].onmouseup = function () { 
            skin.rightButton(this.getAttribute('key'));
        }
        icons[i].onmouseover = function () { 
            skin.execOrder('mouseOver', this.getAttribute('key'));
        }
        icons[i].onmouseout = function () { 
            skin.execOrder('mouseOver', 'null');
        }
    }
    document.onclick  =function () {
        skin.execMouseDown(event, false, 'null');    
    }
    
    document.onmouseup =function () {  
        skin.rightButton('null'); 
    }
}
skin.keyMap = {
    '0': 'language',
    '1': 'characters',
    '2': 'punctuation',
    '4': 'login',
    '5': 'setting'
}
skin.getImgUrl = function (imgSrc) {
    return imgSrc.match(/\w*?\.png/);
}
skin.setImgUrl = function (imgSrc, act) {
    var img =  skin.getImgUrl(imgSrc);    
    img = img[0].split('.'); 
    return (act.flag ? img[0] + '_' + act.type : img[0].replace('_' + act.type,'')) + '.png'; 
}
skin.proccessEvent = function () {
    document.body.onmouseup = function (e) {
        var element = e.target,
            eventType = element.getAttribute('event-type');
        if (e.button == 0) {
            var fnName = config.eventMap[eventType]; 
            if (typeof window.skin[fnName] == 'function') {
                window.skin[fnName](element, eventType);
            }
        }
    }
}
/**
 * 清空盒子
 */
skin.clearBox = function () {
    $('#showBox').html('');
    $('#canvas')[0].getContext('2d').clearRect(0,0,500,500);
}
/**
 * 关闭盒子
 */
skin.proccessCloseBox = function () { 
     $('#settingBox').hide();
}
/**
 * 最小化盒子
 */
skin.proccessMiniSizeBox = function () {
    skin.execOrder('miniApp');
}
/**
 * 恢复默认图片
 */
skin.proccessSetNomal = function () {
    //标识是用默认图片
    $('#isNomal').val('1');
    showHead({file: skin.nomalImgSrc});
    skin.clearBox();
}
/**
 * 使用本地图片
 */
skin.proccesSetLocalImg = function () {
    skin.execOrder('openFolder', '4');
}
/**
 * 保存新头像
 */
skin.proccessSaveHead = function () {
    var options = {
        id: '4',
        text: 'kity猫脸皮肤',
        file: window.openFile
    };
    if($('#isNomal').val() != '1') {
        options['x'] = parseInt($('#rx').val(), 10);
        options['y'] = parseInt($('#ry').val(), 10); 
        options['w'] = parseInt($('#rw').val(), 10); 
        options['h'] = parseInt($('#rh').val(), 10);
    }
    
    skin.execOrder('saveHead', JSON.stringify(options));
    skin.proccessCloseBox();
}
skin.proccessOpenCutBox = function () {
    $('#settingBox').fadeIn();
}
/**
 * 设置皮肤初始状态
 */
skin.initSkin = function (isSkin) {
    // 设置字体显示
    skin.getSysver();    
    // 初始化icon状态
    skin.setIMEStatus();       
    // 绑定状态栏事件
    skin.bindEvent();
    // 绑定皮肤各种事件 
    skin.proccessEvent();
	skin.nomalImgSrc = 'images/nomal.png';
	 // 显示头像
    showHead({file: getHeadImg()});
}
/**
 * 在一支笔中打印日志
 * @param {string} str 打印的内容
 */
function Log(str) {   
    try {
        if(window.external.SyncRequest) { 
            window.external.SyncRequest('log', str);
        } else {   //在浏览器控制台中输出        
            console.log(str);
        }
    } catch (e) {}
}
// 供客户端调用
function setButtonState(key, statu) { 
    var status = config.buttonstatus;
    var id = '';
    key = key || '0';
    id = status[key].id;
    if (typeof skin.g(id) == 'string') {
        return;
    }
    statu =  statu || (skin.g(id).getAttribute('statu') == '0' ? '1' : '0');     
    skin.g(id).src = 'images/icons/' + status[key][statu];
    skin.g(id).setAttribute ('statu', statu);        
}
 function saveHeadSetting(imgSrc) { 
    var headInfo = skin.storage.get('headInfo');
    if (!headInfo) {
        headInfo = {};
    }
    headInfo['imgSrc'] = imgSrc; 
    skin.storage.set('headInfo', headInfo);
 }
 /**
  * 获取头像src
  * @return {string} 头像src
  */
function getHeadImg() { 
    var headInfo = skin.storage.get('headInfo'); 
    var src = (!headInfo) ? skin.nomalImgSrc : headInfo['imgSrc'];
    return src;
}


